@@ -63,7 +63,7 @@ struct isc_lex {
 	LIST(struct inputsource) sources;
 };
 
-static inline isc_result_t
+static isc_result_t
 grow_data(isc_lex_t *lex, size_t *remainingp, char **currp, char **prevp) {
 	char *tmp;
 
@@ -180,7 +180,7 @@ isc_lex_setspecials(isc_lex_t *lex, isc_lexspecials_t specials) {
 	memmove(lex->specials, specials, 256);
 }
 
-static inline isc_result_t
+static isc_result_t
 new_source(isc_lex_t *lex, bool is_file, bool need_close, void *input,
 	   const char *name) {
 	inputsource *source;
@@ -670,6 +670,13 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 		case lexstate_string:
 			if (!escaped && c == '=' &&
 			    (options & ISC_LEXOPT_VPAIR) != 0) {
+				if (remaining == 0U) {
+					result = grow_data(lex, &remaining,
+							   &curr, &prev);
+					if (result != ISC_R_SUCCESS) {
+						goto done;
+					}
+				}
 				INSIST(remaining > 0U);
 				*curr++ = c;
 				*curr = '\0';
@@ -677,19 +684,18 @@ isc_lex_gettoken(isc_lex_t *lex, unsigned int options, isc_token_t *tokenp) {
 				state = lexstate_vpairstart;
 				break;
 			}
-			/* FALLTHROUGH */
+			FALLTHROUGH;
 		case lexstate_vpairstart:
 			if (state == lexstate_vpairstart) {
 				if (c == '"' &&
 				    (options & ISC_LEXOPT_QVPAIR) != 0) {
-					INSIST(remaining > 0U);
 					no_comments = true;
 					state = lexstate_qvpair;
 					break;
 				}
 				state = lexstate_vpair;
 			}
-			/* FALLTHROUGH */
+			FALLTHROUGH;
 		case lexstate_vpair:
 			/*
 			 * EOF needs to be checked before lex->specials[c]
